@@ -31,7 +31,6 @@
 
 #include <telepathy-yell/telepathy-yell.h>
 
-#include <libempathy/empathy-channel-factory.h>
 #include <libempathy/empathy-presence-manager.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 #include <libempathy/empathy-contact-manager.h>
@@ -237,7 +236,8 @@ event_manager_add (EmpathyEventManager *manager,
   event->public.header = g_strdup (header);
   event->public.message = g_strdup (message);
   event->public.must_ack = (func != NULL);
-  event->public.handler_instance = approval->handler_instance;
+  if (approval != NULL)
+    event->public.handler_instance = approval->handler_instance;
   event->inhibit = FALSE;
   event->func = func;
   event->user_data = user_data;
@@ -431,26 +431,6 @@ out:
   g_object_unref (user_data);
 }
 
-static void
-reject_auth_channel_claim_cb (GObject *source,
-    GAsyncResult *result,
-    gpointer user_data)
-{
-  TpChannelDispatchOperation *cdo = TP_CHANNEL_DISPATCH_OPERATION (source);
-  GError *error = NULL;
-
-  if (!tp_channel_dispatch_operation_claim_with_finish (cdo, result, &error))
-    {
-      DEBUG ("Failed to claim channel: %s", error->message);
-
-      g_error_free (error);
-      return;
-    }
-
-  tp_cli_channel_call_close (TP_CHANNEL (user_data), -1,
-      NULL, NULL, NULL, NULL);
-}
-
 static void
 reject_approval (EventManagerApproval *approval)
 {
@@ -472,9 +452,8 @@ reject_approval (EventManagerApproval *approval)
   else if (tp_channel_get_channel_type_id (approval->main_channel)
       == TP_IFACE_QUARK_CHANNEL_TYPE_SERVER_AUTHENTICATION)
     {
-      tp_channel_dispatch_operation_claim_with_async (approval->operation,
-          priv->auth_approver, reject_auth_channel_claim_cb,
-          approval->main_channel);
+      tp_channel_dispatch_operation_close_channels_async (approval->operation,
+          NULL, NULL);
     }
 }
 
@@ -1391,9 +1370,8 @@ empathy_event_manager_init (EmpathyEventManager *manager)
 {
   EmpathyEventManagerPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (manager,
     EMPATHY_TYPE_EVENT_MANAGER, EmpathyEventManagerPriv);
-  TpDBusDaemon *dbus;
   GError *error = NULL;
-  EmpathyChannelFactory *factory;
+  TpAccountManager *am;
 
   manager->priv = priv;
 
@@ -1409,20 +1387,10 @@ empathy_event_manager_init (EmpathyEventManager *manager)
   g_signal_connect (priv->contact_manager, "members-changed",
     G_CALLBACK (event_manager_members_changed_cb), manager);
 
-  dbus = tp_dbus_daemon_dup (&error);
-  if (dbus == NULL)
-    {
-      DEBUG ("Failed to get TpDBusDaemon: %s", error->message);
-      g_error_free (error);
-      return;
-    }
+   am = tp_account_manager_dup ();
 
-  priv->approver = tp_simple_approver_new (dbus, "Empathy.EventManager", FALSE,
-      approve_channels, manager, NULL);
-
-  /* EmpathyTpChat relies on this feature being prepared */
-  tp_base_client_add_connection_features_varargs (priv->approver,
-    TP_CONNECTION_FEATURE_CAPABILITIES, 0);
+  priv->approver = tp_simple_approver_new_with_am (am, "Empathy.EventManager",
+      FALSE, approve_channels, manager, NULL);
 
   /* Private text channels */
   tp_base_client_take_approver_filter (priv->approver,
@@ -1469,7 +1437,7 @@ empathy_event_manager_init (EmpathyEventManager *manager)
    * EmpathyTpChat and its users to not depend on the connection being
    * prepared with capabilities. I chose the former, obviously. :-) */
 
-  priv->auth_approver = tp_simple_approver_new (dbus,
+  priv->auth_approver = tp_simple_approver_new_with_am (am,
       "Empathy.AuthEventManager", FALSE, approve_channels, manager,
       NULL);
 
@@ -1483,11 +1451,6 @@ empathy_event_manager_init (EmpathyEventManager *manager)
           TP_IFACE_CHANNEL_INTERFACE_SASL_AUTHENTICATION,
         NULL));
 
-  factory = empathy_channel_factory_dup ();
-
-  tp_base_client_set_channel_factory (priv->approver,
-      TP_CLIENT_CHANNEL_FACTORY (factory));
-
   if (!tp_base_client_register (priv->approver, &error))
     {
       DEBUG ("Failed to register Approver: %s", error->message);
@@ -1500,8 +1463,7 @@ empathy_event_manager_init (EmpathyEventManager *manager)
       g_error_free (error);
     }
 
-  g_object_unref (factory);
-  g_object_unref (dbus);
+  g_object_unref (am);
 }
 
 EmpathyEventManager *
